@@ -20,6 +20,7 @@ pub struct DirectoryConfig<'a> {
     pub read_only_style: &'a str,
     pub truncation_symbol: &'a str,
     pub home_symbol: &'a str,
+    pub use_os_path_sep: bool,
 }
 
 impl<'a> Default for DirectoryConfig<'a> {
@@ -39,6 +40,7 @@ impl<'a> Default for DirectoryConfig<'a> {
             read_only_style: "red",
             truncation_symbol: "",
             home_symbol: "~",
+            use_os_path_sep: true,
         }
     }
 }
