@@ -1,18 +1,21 @@
 use crate::config::{RootModuleConfig, StarshipConfig};
 use crate::configs::StarshipRootConfig;
 use crate::module::Module;
-use crate::utils::{exec_cmd, CommandOutput};
+use crate::utils::{create_command, exec_timeout, CommandOutput};
 
 use crate::modules;
 use crate::utils::{self, home_dir};
-use clap::ArgMatches;
+use clap::Parser;
 use git2::{ErrorCode::UnbornBranch, Repository, RepositoryState};
 use once_cell::sync::OnceCell;
-use std::collections::{HashMap, HashSet};
+#[cfg(test)]
+use std::collections::HashMap;
+use std::collections::HashSet;
 use std::env;
 use std::ffi::{OsStr, OsString};
 use std::fmt::Debug;
 use std::fs;
+use std::num::ParseIntError;
 use std::path::{Path, PathBuf};
 use std::string::String;
 use std::time::{Duration, Instant};
@@ -37,7 +40,7 @@ pub struct Context<'a> {
     dir_contents: OnceCell<DirContents>,
 
     /// Properties to provide to modules.
-    pub properties: HashMap<&'a str, String>,
+    pub properties: Properties,
 
     /// Pipestatus of processes in pipe
     pub pipestatus: Option<Vec<String>>,
@@ -48,8 +51,8 @@ pub struct Context<'a> {
     /// The shell the user is assumed to be running
     pub shell: Shell,
 
-    /// Construct the right prompt instead of the left prompt
-    pub right: bool,
+    /// Which prompt to print (main, right, ...)
+    pub target: Target,
 
     /// Width of terminal, or zero if width cannot be detected.
     pub width: usize,
@@ -73,53 +76,46 @@ impl<'a> Context<'a> {
     /// Identify the current working directory and create an instance of Context
     /// for it. "logical-path" is used when a shell allows the "current working directory"
     /// to be something other than a file system path (like powershell provider specific paths).
-    pub fn new(arguments: ArgMatches) -> Context {
+    pub fn new(arguments: Properties, target: Target) -> Context<'a> {
         let shell = Context::get_shell();
 
         // Retrieve the "current directory".
         // If the path argument is not set fall back to the OS current directory.
         let path = arguments
-            .value_of("path")
-            .map(PathBuf::from)
+            .path
+            .clone()
             .or_else(|| env::current_dir().ok())
             .or_else(|| env::var("PWD").map(PathBuf::from).ok())
-            .or_else(|| arguments.value_of("logical_path").map(PathBuf::from))
+            .or_else(|| arguments.logical_path.clone())
             .unwrap_or_default();
 
         // Retrieve the "logical directory".
         // If the path argument is not set fall back to the PWD env variable set by many shells
         // or to the other path.
         let logical_path = arguments
-            .value_of("logical_path")
-            .map(PathBuf::from)
+            .logical_path
+            .clone()
             .or_else(|| env::var("PWD").map(PathBuf::from).ok())
             .unwrap_or_else(|| path.clone());
 
-        Context::new_with_shell_and_path(arguments, shell, path, logical_path)
+        Context::new_with_shell_and_path(arguments, shell, target, path, logical_path)
     }
 
     /// Create a new instance of Context for the provided directory
     pub fn new_with_shell_and_path(
-        arguments: ArgMatches,
+        properties: Properties,
         shell: Shell,
+        target: Target,
         path: PathBuf,
         logical_path: PathBuf,
-    ) -> Context {
+    ) -> Context<'a> {
         let config = StarshipConfig::initialize();
 
-        // Unwrap the clap arguments into a simple hashtable
-        let properties: HashMap<&str, std::string::String> = arguments
-            .args
-            .iter()
-            .filter(|(_, v)| !v.vals.is_empty())
-            .map(|(a, b)| (*a, b.vals.first().cloned().unwrap().into_string().unwrap()))
-            .collect();
-
-        let pipestatus = arguments
-            .values_of("pipestatus")
+        let pipestatus = properties
+            .pipestatus
+            .as_deref()
             .map(Context::get_and_flatten_pipestatus)
             .flatten();
-
         log::trace!("Received completed pipestatus of {:?}", pipestatus);
 
         // Canonicalize the current path to resolve symlinks, etc.
@@ -133,13 +129,7 @@ impl<'a> Context<'a> {
             .as_ref()
             .map_or_else(StarshipRootConfig::default, StarshipRootConfig::load);
 
-        let right = arguments.is_present("right");
-
-        let width = arguments
-            .value_of("terminal_width")
-            .and_then(|w| w.parse().ok())
-            .or_else(|| terminal_size().map(|(w, _)| w.0 as usize))
-            .unwrap_or(80);
+        let width = properties.terminal_width;
 
         Context {
             config,
@@ -150,7 +140,7 @@ impl<'a> Context<'a> {
             dir_contents: OnceCell::new(),
             repo: OnceCell::new(),
             shell,
-            right,
+            target,
             width,
             #[cfg(test)]
             env: HashMap::new(),
@@ -207,12 +197,13 @@ impl<'a> Context<'a> {
     }
 
     /// Reads and appropriately flattens multiple args for pipestatus
-    pub fn get_and_flatten_pipestatus(args: clap::Values) -> Option<Vec<String>> {
+    // TODO: Replace with value_delimiter = ' ' clap option?
+    pub fn get_and_flatten_pipestatus(args: &[String]) -> Option<Vec<String>> {
         // Due to shell differences, we can potentially receive individual or space
         // separated inputs, e.g. "0","1","2","0" is the same as "0 1 2 0" and
         // "0 1", "2 0". We need to accept all these formats and return a Vec<String>
         let parsed_vals = args
-            .into_iter()
+            .iter()
             .map(|x| x.split_ascii_whitespace())
             .flatten()
             .map(|x| x.to_string())
@@ -301,12 +292,17 @@ impl<'a> Context<'a> {
             "tcsh" => Shell::Tcsh,
             "nu" => Shell::Nu,
             "xonsh" => Shell::Xonsh,
+            "cmd" => Shell::Cmd,
             _ => Shell::Unknown,
         }
     }
 
+    // TODO: This should be used directly by clap parse
     pub fn get_cmd_duration(&self) -> Option<u128> {
-        self.properties.get("cmd_duration")?.parse::<u128>().ok()
+        self.properties
+            .cmd_duration
+            .as_deref()
+            .and_then(|cd| cd.parse::<u128>().ok())
     }
 
     /// Execute a command and return the output on stdout and stderr if successful
@@ -316,16 +312,27 @@ impl<'a> Context<'a> {
         cmd: T,
         args: &[U],
     ) -> Option<CommandOutput> {
+        log::trace!(
+            "Executing command {:?} with args {:?} from context",
+            cmd,
+            args
+        );
         #[cfg(test)]
         {
             let command = crate::utils::display_command(&cmd, args);
-            if let Some(output) = self.cmd.get(command.as_str()) {
-                return output.clone();
+            if let Some(output) = self
+                .cmd
+                .get(command.as_str())
+                .cloned()
+                .or_else(|| crate::utils::mock_cmd(&cmd, args))
+            {
+                return output;
             }
         }
-        exec_cmd(
-            &cmd,
-            args,
+        let mut cmd = create_command(cmd).ok()?;
+        cmd.args(args).current_dir(&self.current_dir);
+        exec_timeout(
+            &mut cmd,
             Duration::from_millis(self.root_config.command_timeout),
         )
     }
@@ -555,9 +562,71 @@ pub enum Shell {
     Tcsh,
     Nu,
     Xonsh,
+    Cmd,
     Unknown,
 }
 
+fn default_width() -> usize {
+    terminal_size().map_or(80, |(w, _)| w.0 as usize)
+}
+
+/// Which kind of prompt target to print (main prompt, rprompt, ...)
+#[derive(Debug, Clone, Copy, PartialEq)]
+pub enum Target {
+    Main,
+    Right,
+    Continuation,
+}
+
+/// Properties as passed on from the shell as arguments
+#[derive(Parser, Debug)]
+pub struct Properties {
+    /// The status code of the previously run command
+    #[clap(short = 's', long = "status")]
+    pub status_code: Option<i32>,
+    /// Bash, Fish and Zsh support returning codes for each process in a pipeline.
+    #[clap(long)]
+    pipestatus: Option<Vec<String>>,
+    /// The width of the current interactive terminal.
+    #[clap(short = 'w', long, default_value_t=default_width())]
+    terminal_width: usize,
+    /// The path that the prompt should render for.
+    #[clap(short, long)]
+    path: Option<PathBuf>,
+    /// The logical path that the prompt should render for.
+    /// This path should be a virtual/logical representation of the PATH argument.
+    #[clap(short = 'P', long)]
+    logical_path: Option<PathBuf>,
+    /// The execution duration of the last command, in milliseconds
+    #[clap(short = 'd', long)]
+    pub cmd_duration: Option<String>,
+    /// The keymap of fish/zsh/cmd
+    #[clap(short = 'k', long, default_value = "viins")]
+    pub keymap: String,
+    /// The number of currently running jobs
+    #[clap(short, long, default_value_t, parse(try_from_str=parse_jobs))]
+    pub jobs: i64,
+}
+
+impl Default for Properties {
+    fn default() -> Self {
+        Properties {
+            status_code: None,
+            pipestatus: None,
+            terminal_width: default_width(),
+            path: None,
+            logical_path: None,
+            cmd_duration: None,
+            keymap: "viins".to_string(),
+            jobs: 0,
+        }
+    }
+}
+
+fn parse_jobs(jobs: &str) -> Result<i64, ParseIntError> {
+    jobs.trim().parse::<i64>()
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -644,8 +713,9 @@ mod tests {
         // Mock navigation into the symlink path
         let test_path = path_symlink.join("yyy");
         let context = Context::new_with_shell_and_path(
-            ArgMatches::default(),
+            Default::default(),
             Shell::Unknown,
+            Target::Main,
             test_path.clone(),
             test_path.clone(),
         );
@@ -669,8 +739,9 @@ mod tests {
         // Mock navigation to a directory which does not exist on disk
         let test_path = Path::new("/path_which_does_not_exist").to_path_buf();
         let context = Context::new_with_shell_and_path(
-            ArgMatches::default(),
+            Default::default(),
             Shell::Unknown,
+            Target::Main,
             test_path.clone(),
             test_path.clone(),
         );
@@ -689,8 +760,9 @@ mod tests {
         // Mock navigation to a directory which does not exist on disk
         let test_path = Path::new("~/path_which_does_not_exist").to_path_buf();
         let context = Context::new_with_shell_and_path(
-            ArgMatches::default(),
+            Default::default(),
             Shell::Unknown,
+            Target::Main,
             test_path.clone(),
             test_path.clone(),
         );
